@@ -1,35 +1,9 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Assistant of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 #include "tracer.h"
 
 #include "helpenginewrapper.h"
 #include "../shared/collectionconfiguration.h"
-#include "../help/qhelpengine_p.h"
 
 #include <QtCore/QDateTime>
 #include <QtCore/QFileInfo>
@@ -723,8 +697,8 @@ void HelpEngineWrapperPrivate::qchFileChanged(const QString &fileName)
 void HelpEngineWrapperPrivate::checkDocFilesWatched()
 {
     TRACE_OBJ
-    const int watchedFilesCount = m_qchWatcher->files().count();
-    const int docFilesCount = m_helpEngine->registeredDocumentations().count();
+    const int watchedFilesCount = m_qchWatcher->files().size();
+    const int docFilesCount = m_helpEngine->registeredDocumentations().size();
     if (watchedFilesCount != docFilesCount) {
         qWarning("Strange: Have %d docs, but %d are being watched",
                  watchedFilesCount, docFilesCount);
