@@ -9,11 +9,10 @@ namespace litehtml
 	{
 		tstring	m_text;
 	public:
-		el_cdata(const std::shared_ptr<litehtml::document>& doc);
-		virtual ~el_cdata();
+		explicit el_cdata(const std::shared_ptr<litehtml::document>& doc);
 
-		virtual void	get_text(tstring& text) override;
-		virtual void	set_data(const tchar_t* data) override;
+		void get_text(tstring& text) override;
+		void set_data(const tchar_t* data) override;
 	};
 }
 
