@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Designer of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "objectinspectormodel_p.h"
 
@@ -72,8 +47,10 @@ static bool sameIcon(const QIcon &i1, const QIcon &i2)
     return i1.cacheKey() == i2.cacheKey();
 }
 
-static inline bool isNameColumnEditable(const QObject *)
+static inline bool isNameColumnEditable(const QObject *o)
 {
+    if (auto *action = qobject_cast<const QAction *>(o))
+        return !action->isSeparator();
     return true;
 }
 
@@ -301,7 +278,7 @@ namespace qdesigner_internal {
             }
             // Add button groups
             if (!buttonGroups.isEmpty()) {
-                for (QButtonGroup *group : qAsConst(buttonGroups))
+                for (QButtonGroup *group : std::as_const(buttonGroups))
                     createModelRecursion(fwi, object, group, model, ctx);
             }
         } // has children
