@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Designer of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qdesigner_propertycommand_p.h"
 #include "qdesigner_utils_p.h"
@@ -651,8 +626,14 @@ PropertyHelper::PropertyHelper(QObject* object,
         m_parentWidget = (qobject_cast<QWidget*>(object))->parentWidget();
         m_objectType = OT_Widget;
     } else {
-        if (const QAction *action = qobject_cast<const QAction *>(m_object))
-            m_objectType = action->associatedWidgets().isEmpty() ? OT_FreeAction : OT_AssociatedAction;
+        if (const QAction *action = qobject_cast<const QAction *>(m_object)) {
+            const QObjectList associatedObjects = action->associatedObjects();
+            auto it = std::find_if(associatedObjects.cbegin(), associatedObjects.cend(),
+                                   [](QObject *obj) {
+                                       return qobject_cast<QWidget *>(obj) != nullptr;
+                                   });
+            m_objectType = (it == associatedObjects.cend()) ? OT_FreeAction : OT_AssociatedAction;
+        }
     }
 
     if(debugPropertyCommands)
@@ -1412,7 +1393,7 @@ bool AddDynamicPropertyCommand::init(const QObjectList &selection, QObject *curr
 void AddDynamicPropertyCommand::redo()
 {
     QDesignerFormEditorInterface *core = formWindow()->core();
-    for (QObject *obj : qAsConst(m_selection)) {
+    for (QObject *obj : std::as_const(m_selection)) {
         QDesignerDynamicPropertySheetExtension *dynamicSheet = qt_extension<QDesignerDynamicPropertySheetExtension*>(core->extensionManager(), obj);
         dynamicSheet->addDynamicProperty(m_propertyName, m_value);
         if (QDesignerPropertyEditorInterface *propertyEditor = formWindow()->core()->propertyEditor()) {
@@ -1425,7 +1406,7 @@ void AddDynamicPropertyCommand::redo()
 void AddDynamicPropertyCommand::undo()
 {
     QDesignerFormEditorInterface *core = formWindow()->core();
-    for (QObject *obj : qAsConst(m_selection)) {
+    for (QObject *obj : std::as_const(m_selection)) {
         QDesignerPropertySheetExtension *sheet = qt_extension<QDesignerPropertySheetExtension*>(core->extensionManager(), obj);
         QDesignerDynamicPropertySheetExtension *dynamicSheet = qt_extension<QDesignerDynamicPropertySheetExtension*>(core->extensionManager(), obj);
         dynamicSheet->removeDynamicProperty(sheet->indexOf(m_propertyName));
